from Products.Archetypes.public import listTypes
from Products.Archetypes.Extensions.utils import installTypes, install_subskin
from Products.ATAudio.config import PROJECTNAME, GLOBALS
from Products.CMFCore.utils import getToolByName
from Products.CMFCore.CMFCorePermissions import ManagePortal
from StringIO import StringIO

def install_predicates(self, out):
    """ install predicates in the content type registry """
    ctr = getToolByName(self, 'content_type_registry')

    if 'macosx_regex' not in ctr.predicate_ids:
        ctr.addPredicate('macosx_regex', 'name_regex' )
        ctr.getPredicate('macosx_regex').edit('._+')
        ctr.assignTypeName('macosx_regex', 'File')
        ctr.reorderPredicate('macosx_regex', 0)
        out.write('Installed CTR Predicate for ignoring MacOS X resource forks.\n')
    else:
        out.write('Predicate for ignoring MacOS X resource forks was already installed.\n')

    if 'mp3_ext' not in ctr.predicate_ids:
        ctr.addPredicate('mp3_ext', 'extension' )
        ctr.getPredicate('mp3_ext').edit('mp3')
        ctr.assignTypeName('mp3_ext', 'ATAudio')
        ctr.reorderPredicate('mp3_ext', 1)
        out.write('Installed CTR Predicate for .mp3 -> ATAudio.\n')
    else:
        out.write('Predicate for .mp3 -> ATAudio was already installed.\n')

    if ctr.getPredicate('audio'):
        out.write('Removing existing audio predicate.\n')
        ctr.removePredicate('audio')
    ctr.addPredicate('audio', 'major_minor')
    ctr.getPredicate('audio').edit(major='audio', minor='')
    ctr.assignTypeName('audio', 'ATAudio')
    ctr.reorderPredicate('audio', 2)
    out.write('Installed predicate for MIME type audio.\n')

def install_actions(self, out, GLOBALS):
    """ Install custom podcasting actionsn into portal_actions """
    
    pa=getToolByName(self, 'portal_actions')
    pai=getToolByName(self, 'portal_actionicons')
    
    if pai.queryActionInfo('plone', 'podcast'):
        # If the action is found, then remove the icon.
        pai.removeActionIcon('plone','podcast')
    
    pai.addActionIcon(category='plone', action_id='podcast', icon_expr='podcast_icon.png', title='RSS2 Syndication')
    
    # Add actionInfo  action to portal_actions. Delete old versions before adding, if exist one
    action_tool = getToolByName(self, 'portal_actions')
    actions_id = [a.id for a in action_tool._actions]
    selections = [actions_id.index(a) for a in actions_id if a in ('podcast','setup_podcast')]
    pa.deleteActions(selections=selections)

    pa.addAction(  id='podcast',
                    name='Podcast',
                    action='string:${object_url}/' + 'podcast.xml',
#                    condition='python: folder==object and portal.portal_syndication.isSyndicationAllowed(object)',
                    # show podcast icon even if portal syndication is not enabled
                    # only show icon if object is a Smart Folder
                    condition="python: object.meta_type in ('ATTopic', )",
                    permission='View',
                    category='document_actions',
                    visible=1)
                    
# commented out since there is no setup_podcast template yet
#
#     pa.addAction(  id='setup_podcast',
#                     name='Setup Podcasting',
#                     action='string:${object_url}/' + 'setup_podcast',
#                     condition='python: folder==object and portal.portal_syndication.isSyndicationAllowed(object)',
#                     permission=('Manage properties',),
#                     category='folder',
#                     visible=1)

    out.write("Installed podcasting actions.\n")

def install_properties(self, out):
    """ Install properties for ATAudio """

    if not hasattr(self.portal_properties, 'ataudio_properties'):
        self.portal_properties.addPropertySheet('ataudio_properties', 'ATAudio properties')
    
    props = self.portal_properties.ataudio_properties

    if not hasattr(props, 'media_server'):
        props._setProperty('media_server', "", 'string')
        
    if not hasattr(props, 'max_file_size'):
        props._setProperty('max_file_size', "", 'float')

    out.write("Installed global ATAudio properties.\n")
    
def install_navprops(self, out):
    """
    Register ATAudioFolder as folderish content in plone, so it will
    get the appropriate folder_contents tabs, and use view actions in listings
    """
    props = self.portal_properties.site_properties
    tabs = getattr(props, 'use_folder_tabs')
    contents = getattr(props, 'use_folder_contents')

    if 'ATAudioFolder' not in tabs:
        newtabs = list(tabs)
        newtabs.append('ATAudioFolder')
        props._updateProperty('use_folder_tabs', newtabs)

    if 'ATAudioFolder' not in contents:
        newcontents = list(contents)
        newcontents.append('ATAudioFolder')
        props._updateProperty('use_folder_contents', newcontents)

    useView = getattr(props, 'typesUseViewActionInListings', None)
    if useView is not None:
        if 'ATAudio' not in useView:
            props._updateProperty('typesUseViewActionInListings', list(useView) + ['ATAudio']) 

    out.write("Installed ATAudio navigation properties.\n")

def install_css(self, out):
    """ install custom CSS used by ATAudio """
    portal_css = getToolByName(self, 'portal_css')
    portal_css.manage_addStylesheet(id = 'ataudio.css',
                                    expression = "python:object.getTypeInfo().getId() in ['Recordings','ATAudioFolder','ATAudio',]",
                                    media = 'all',
                                    title = 'ATAudio styles',
                                    enabled = True)
                                    
    out.write("Installed CSS for ATAudio into portal_css.\n")

def install(self):

    out = StringIO()

    install_predicates(self, out)    
    install_actions(self, out, GLOBALS)
    install_properties(self, out)
    install_navprops(self, out)    
    install_css(self, out)
    installTypes(self, out, listTypes(PROJECTNAME), PROJECTNAME)
    install_subskin(self, out, GLOBALS)
    
    print >> out, "Successfully installed %s." % PROJECTNAME
    return out.getvalue()
                                    
def uninstall(self):
    out = StringIO()
        
    print >> out, "Successfully uninstalled %s." % PROJECTNAME
    return out.getvalue()
