#  Recordings: container for ATAudioFolder objects
#  Copyright (c) 2003-2005 Nate Aune
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
""" 
   Recordings is a container for ATAudioFolder objects. 
   For example, you could use it to show a list of all of your CDs.
"""
__author__  = 'Nate Aune <natea@jazkarta.com>'
__docformat__ = 'restructuredtext'

try:
    from Products.LinguaPlone.public import *
except:
    # no multilingual support
    from Products.Archetypes.public import *

from Products.CMFCore import CMFCorePermissions

schema = BaseFolderSchema +  Schema((
    StringField('title',
                required=1,
                searchable=1,
                accessor='Title',
                widget=StringWidget(label="Title",
                                    label_msgid="label_cd_title",
                                    description="The title for this list of recordings",
                                    description_msgid="desc_recordings_title",
                                    i18n_domain="ataudio"),
                ),    
    StringField('description',
                storage=MetadataStorage(),
                searchable=1,
                accessor='Description',
                widget=TextAreaWidget(label='Description',
                                    label_msgid="label_recordings_description",
                                    description='Description for this list of recordings.',
                                    description_msgid="desc_recordings_description",
                                    i18n_domain="ataudio"), 
               ),
    ))
        
class Recordings(OrderedBaseFolder):
    """
        A recordings folder is a container for your CDs.
    """
    schema = schema
    filter_content_types = 1
    allowed_content_types = 'ATAudioFolder',
    meta_type = 'Recordings'
    archetype_name = 'Recordings'
    
    _at_rename_after_creation = True

    content_icon = 'folder_icon.gif'
    
    actions = ({
       'id': 'view',
        'name': 'View',
        'action': 'string:${object_url}/recordings_view',
        'permissions': (CMFCorePermissions.View,)
        },
        {'id': 'references',
          'name': 'References',
          'action': 'string:${object_url}/reference_edit',
          'permissions': (CMFCorePermissions.ModifyPortalContent,),
          'visible':0},
        {'id': 'metadata',
          'name': 'Properties',
          'action': 'string:${object_url}/base_metadata',
          'permissions': (CMFCorePermissions.ModifyPortalContent,),
          'visible':0})    

registerType(Recordings)
